<?php

namespace Drupal\user_ref_field_cache_context\CacheContext;

use Drupal\Core\Cache\CacheableMetadata;
use Drupal\Core\Cache\Context\CalculatedCacheContextInterface;
use Drupal\Core\Cache\Context\UserCacheContextBase;
use Drupal\user\Entity\User;

/**
 * Defines the QueryArgsCacheContext service, for "per query args" caching.
 *
 * Cache context ID: 'user.ref_field' (to vary by a reference field value).
 * Calculated cache context ID: 'user.ref_field:%key', e.g.'user.ref_field:foo'
 * (to vary by the 'foo' user field's value).
 */
class UserReferenceField extends UserCacheContextBase implements CalculatedCacheContextInterface {

  /**
   * {@inheritdoc}
   */
  public static function getLabel() {
    return t('User reference field');
  }

  /**
   * {@inheritdoc}
   */
  public function getContext($field = NULL) {
    if (empty($field)) {
      return '';
    }
    $current_user_id = $this->user->getAccount()->id();
    // Load user object.
    $user = User::load($current_user_id);
    if (!$user->hasField($field)) {
      return '?valueless?';
    }
    $field_val = $user->get($field);
    $value = $field_val->target_id ?? '?valueless?';
    return $value;
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheableMetadata($parameter = NULL) {
    return new CacheableMetadata();
  }

}
